@@ -6,7 +6,7 @@ require_once('Net/Sieve.php');
  * Ingo_Driver_timsieved:: Implements the Sieve_Driver api to allow scripts to
  * be installed and set active via a Cyrus timsieved server.
  *
- * $Horde: ingo/lib/Driver/timsieved.php,v 1.15.10.11 2009/01/06 15:24:35 jan Exp $
+ * $Horde: ingo/lib/Driver/timsieved.php,v 1.15.10.14 2010-07-06 13:53:30 jan Exp $
  *
  * Copyright 2003-2009 The Horde Project (http://www.horde.org/)
  *
@@ -50,14 +50,12 @@ class Ingo_Driver_timsieved extends Ingo_Driver {
     }
 
     /**
-     * Connect to the sieve server.
-     *
-     * @return mixed  True on success, PEAR_Error on false.
+     * Connects to the sieve server.
      */
     function _connect()
     {
         if (!empty($this->_sieve)) {
-            return true;
+            return;
         }
 
         if (empty($this->_params['admin'])) {
@@ -71,17 +69,34 @@ class Ingo_Driver_timsieved extends Ingo_Driver {
                                        $this->_params['port'],
                                        $this->_params['logintype'],
                                        Ingo::getUser(false),
+                                       $this->_params['debug'],
                                        false,
-                                       false,
-                                       $this->_params['usetls']);
+                                       $this->_params['usetls'],
+                                       null,
+                                       array($this, '_debug'));
 
         $res = $this->_sieve->getError();
         if (is_a($res, 'PEAR_Error')) {
             unset($this->_sieve);
             return $res;
-        } else {
-            return true;
         }
+
+        /* BC for older Net_Sieve versions that don't allow specify the debug
+         * handler in the constructor. */
+        if (!empty($this->_params['debug'])) {
+            $this->_sieve->setDebug(true, array($this, '_debug'));
+        }
+    }
+
+    /**
+     * Routes the Sieve protocol log to the Horde log.
+     *
+     * @param Net_Sieve $sieve  A Net_Sieve object.
+     * @param string $message   The tracked Sieve communication.
+     */
+    function _debug($sieve, $message)
+    {
+        Horde::logMessage($message, __FILE__, __LINE__, PEAR_LOG_DEBUG);
     }
 
     /**
