@@ -14,7 +14,7 @@ define('INGO_SCRIPT_FILTER_SEEN', 2);
  * The Ingo_Script:: class provides a common abstracted interface to the
  * script-generation subclasses.
  *
- * $Horde: ingo/lib/Script.php,v 1.30.10.10 2008/09/12 17:00:57 jan Exp $
+ * $Horde: ingo/lib/Script.php,v 1.30.10.11 2009-12-21 23:19:05 jan Exp $
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/asl.php.
@@ -120,11 +120,32 @@ class Ingo_Script {
         $script = basename($script);
         include_once dirname(__FILE__) . '/Script/' . $script . '.php';
         $class = 'Ingo_Script_' . $script;
+
+        if (!isset($params['spam_compare'])) {
+            $params['spam_compare'] = $GLOBALS['conf']['spam']['compare'];
+        }
+        if (!isset($params['spam_header'])) {
+            $params['spam_header'] = $GLOBALS['conf']['spam']['header'];
+        }
+        if (!isset($params['spam_char'])) {
+            $params['spam_char'] = $GLOBALS['conf']['spam']['char'];
+        }
+        if ($script == 'sieve') {
+            if (!isset($params['date_format'])) {
+                $params['date_format'] = $GLOBALS['prefs']->getValue('date_format');;
+            }
+            if (!isset($params['time_format'])) {
+                // %R and %r don't work on Windows, but who runs a Sieve
+                // backend on a Windows server?
+                $params['time_format'] = $GLOBALS['prefs']->getValue('twentyFour') ? '%R' : '%r';
+            }
+        }
+
         if (class_exists($class)) {
             return new $class($params);
-        } else {
-            return PEAR::raiseError(sprintf(_("Unable to load the definition of %s."), $class));
         }
+
+        return PEAR::raiseError(sprintf(_("Unable to load the definition of %s."), $class));
     }
 
     /**
@@ -134,19 +155,23 @@ class Ingo_Script {
      */
     function Ingo_Script($params = array())
     {
-        global $registry;
-
         $this->_params = $params;
 
+        if (!isset($GLOBALS['registry'])) {
+            return;
+        }
+
         /* Determine if ingo should handle the blacklist. */
         $key = array_search(INGO_STORAGE_ACTION_BLACKLIST, $this->_categories);
-        if ($key !== false && ($registry->hasMethod('mail/blacklistFrom') != 'ingo')) {
+        if ($key !== false &&
+            $GLOBALS['registry']->hasMethod('mail/blacklistFrom') != 'ingo') {
             unset($this->_categories[$key]);
         }
 
         /* Determine if ingo should handle the whitelist. */
         $key = array_search(INGO_STORAGE_ACTION_WHITELIST, $this->_categories);
-        if ($key !== false && ($registry->hasMethod('mail/whitelistFrom') != 'ingo')) {
+        if ($key !== false &&
+            $GLOBALS['registry']->hasMethod('mail/whitelistFrom') != 'ingo') {
             unset($this->_categories[$key]);
         }
     }
